Translator

Trait Translator 

pub trait Translator {
    // Required method
    fn translate(&self, key: &str) -> String;
}

Required Methods

fn translate(&self, key: &str) -> String

Translates a given key into its corresponding string representation.

If the translation key is unknown, return the key as a String

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors