TableColumnConfig

Struct TableColumnConfig 

pub struct TableColumnConfig { /* private fields */ }
Specifies the properties of a column, like its width range.

Implementations

Source

impl Column

pub fn auto() -> Column

Automatically sized based on content.

If you have many thousands of rows and are therefore using TableBody::rows or TableBody::heterogeneous_rows, then the automatic size will only be based on the currently visible rows.

pub fn auto_with_initial_suggestion(suggested_width: f32) -> Column

Automatically sized.

The given fallback is a loose suggestion, that may be used to wrap cell contents, if they contain a wrapping layout. In most cases though, the given value is ignored.

pub fn initial(width: f32) -> Column

With this initial width.

pub fn exact(width: f32) -> Column

Always this exact width, never shrink or grow.

pub fn remainder() -> Column

Take all the space remaining after the other columns have been sized.

If you have multiple Column::remainder they all share the remaining space equally.

pub fn resizable(self, resizable: bool) -> Column

Can this column be resized by dragging the column separator?

If you don’t call this, the fallback value of TableBuilder::resizable is used (which by default is false).

pub fn clip(self, clip: bool) -> Column

If true: Allow the column to shrink enough to clip the contents. If false: The column will always be wide enough to contain all its content.

Clipping can make sense if you expect a column to contain a lot of things, and you don’t want it too take up too much space. If you turn on clipping you should also consider calling Self::at_least.

Default: false.

pub fn at_least(self, minimum: f32) -> Column

Won’t shrink below this width (in points).

Default: 0.0

pub fn at_most(self, maximum: f32) -> Column

Won’t grow above this width (in points).

Default: f32::INFINITY

pub fn range(self, range: impl Into<Rangef>) -> Column

Allowed range of movement (in points), if in a resizable Table.

pub fn auto_size_this_frame(self, auto_size_this_frame: bool) -> Column

If set, the column will be automatically sized based on the content this frame.

Do not set this every frame, just on a specific action.